==> lxqt-l10n_0.12.0.orig.tar.xz: lxqt-l10n-0.12.0/lxqt-powermanagement/lxqt-config-powermanagement/lxqt-config-powermanagement_da.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="da">
<context>
    <name>BatteryWatcherSettings</name>
    <message>
        <location filename="../../../batterywatchersettings.ui" line="14"/>
        <source>Battery Watcher Settings</source>
        <translation>Indstillinger for overvågning af batteri</translation>
    </message>
    <message>
        <location filename="../../../batterywatchersettings.ui" line="26"/>
        <source>E&amp;nable Battery Watcher</source>
        <translation>&amp;Aktivér overvågning af batteri</translation>
    </message>
    <message>
        <location filename="../../../batterywatchersettings.ui" line="54"/>
        <source>Warning:</source>
        <translation>Advarsel:</translation>
    </message>
    <message>
        <location filename="../../../batterywatchersettings.ui" line="67"/>
        <source> seconds</source>
        <translation> sekunder</translation>
    </message>
    <message>
        <location filename="../../../batterywatchersettings.ui" line="77"/>
        <source>Level is low at:</source>
        <translation>Niveau er lavt ved:</translation>
    </message>
    <message>
        <location filename="../../../batterywatchersettings.ui" line="90"/>
        <source> %</source>
        <translation> %</translation>
    </message>
    <message>
        <location filename="../../../batterywatchersettings.ui" line="111"/>
        <source>Use icons from theme:</source>
        <translation>Brug ikoner fra tema:</translation>
    </message>
    <message>
        <location filename="../../../batterywatchersettings.ui" line="125"/>
        <location filename="../../../batterywatchersettings.cpp" line="93"/>
        <source>Preview</source>
        <translation>Forhåndsvisning</translation>
    </message>
    <message>
        <location filename="../../../batterywatchersettings.ui" line="162"/>
        <source>Charging</source>
        <translation>Oplader</translation>
    </message>
    <message>
        <location filename="../../../batterywatchersettings.ui" line="200"/>
        <source>Discharging</source>
        <translation>Aflader</translation>
    </message>
    <message>
        <location filename="../../../batterywatchersettings.ui" line="41"/>
        <source>When power is low then:</source>
        <translation>Når strøm er lavt:</translation>
    </message>
    <message>
        <location filename="../../../batterywatchersettings.ui" line="97"/>
        <source>Show icon:</source>
        <translation>Vis ikon:</translation>
    </message>
    <message>
        <location filename="../../../batterywatchersettings.cpp" line="93"/>
        <source>built in</source>
        <translation>indbygget</translation>
    </message>
    <message>
        <location filename="../../../batterywatchersettings.cpp" line="98"/>
        <source>Level: %1%</source>
        <translation>Niveau: %1%</translation>
    </message>
</context>
<context>
    <name>IdlenessWatcherSettings</name>
    <message>
        <location filename="../../../idlenesswatchersettings.ui" line="14"/>
        <source>Form</source>
        <translation>Formular</translation>
    </message>
    <message>
        <location filename="../../../idlenesswatchersettings.ui" line="20"/>
        <source>Enab&amp;le Idleness Watcher</source>
        <translation>&amp;Aktivér overvågning af tomgang</translation>
    </message>
    <message>
        <location filename="../../../idlenesswatchersettings.ui" line="41"/>
        <source>When idle then:</source>
        <translation>Ved tomgang:</translation>
    </message>
    <message>
        <location filename="../../../idlenesswatchersettings.ui" line="60"/>
        <source>Idle time:</source>
        <translation>Tomgangstid:</translation>
    </message>
    <message>
        <location filename="../../../idlenesswatchersettings.ui" line="73"/>
        <source> minutes</source>
        <translation> minutter</translation>
    </message>
    <message>
        <location filename="../../../idlenesswatchersettings.ui" line="86"/>
        <source> seconds</source>
        <translation> sekunder</translation>
    </message>
</context>
<context>
    <name>LidWatcherSettings</name>
    <message>
        <location filename="../../../lidwatchersettings.ui" line="14"/>
        <source>Form</source>
        <translation>Formular</translation>
    </message>
    <message>
        <location filename="../../../lidwatchersettings.ui" line="26"/>
        <source>Enable &amp;Lid Watcher</source>
        <translation>&amp;Aktivér overvågning af låg</translation>
    </message>
    <message>
        <location filename="../../../lidwatchersettings.ui" line="41"/>
        <source>Action when lid is closed</source>
        <translation>Handling når låget lukkes</translation>
    </message>
    <message>
        <location filename="../../../lidwatchersettings.ui" line="53"/>
        <location filename="../../../lidwatchersettings.ui" line="118"/>
        <source>On Battery</source>
        <translation>På batteri</translation>
    </message>
    <message>
        <location filename="../../../lidwatchersettings.ui" line="61"/>
        <source>Nothing</source>
        <translation>Intet</translation>
    </message>
    <message>
        <location filename="../../../lidwatchersettings.ui" line="66"/>
        <source>Suspend</source>
        <translation>Hvile</translation>
    </message>
    <message>
        <location filename="../../../lidwatchersettings.ui" line="71"/>
        <source>Hibernate</source>
        <translation>Dvale</translation>
    </message>
    <message>
        <location filename="../../../lidwatchersettings.ui" line="76"/>
        <source>Shut down</source>
        <translation>Luk ned</translation>
    </message>
    <message>
        <location filename="../../../lidwatchersettings.ui" line="84"/>
        <location filename="../../../lidwatchersettings.ui" line="128"/>
        <source>On AC</source>
        <translation>På strømforsyning</translation>
    </message>
    <message>
        <location filename="../../../lidwatchersettings.ui" line="97"/>
        <source>When &amp;using external monitor</source>
        <translation>&amp;Når der bruges ekstern skærm</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../../../mainwindow.cpp" line="34"/>
        <source>Power Management Settings</source>
        <translation>Indstillinger for strømstyring</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.cpp" line="37"/>
        <source>Battery</source>
        <translation>Batteri</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.cpp" line="41"/>
        <source>Lid</source>
        <translation>Låg</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.cpp" line="45"/>
        <source>Idle</source>
        <translation>Tomgang</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../../helpers.cpp" line="35"/>
        <source>Nothing</source>
        <translation>Intet</translation>
    </message>
    <message>
        <location filename="../../../helpers.cpp" line="36"/>
        <source>Lock screen</source>
        <translation>Lås skærm</translation>
    </message>
    <message>
        <location filename="../../../helpers.cpp" line="37"/>
        <source>Suspend</source>
        <translation>Hvile</translation>
    </message>
    <message>
        <location filename="../../../helpers.cpp" line="38"/>
        <source>Hibernate</source>
        <translation>Dvale</translation>
    </message>
    <message>
        <location filename="../../../helpers.cpp" line="39"/>
        <source>Shutdown</source>
        <translation>Luk ned</translation>
    </message>
</context>
</TS>

==> lxqt-l10n-0.13.0_p20181121.tar.xz: lxqt-l10n-0.13.0_p20181121/lxqt-powermanagement/lxqt-config-powermanagement/lxqt-config-powermanagement_da.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="da">
<context>
    <name>BatteryWatcherSettings</name>
    <message>
        <location filename="../../../batterywatchersettings.ui" line="14"/>
        <source>Battery Watcher Settings</source>
        <translation>Indstillinger for overvågning af batteri</translation>
    </message>
    <message>
        <location filename="../../../batterywatchersettings.ui" line="26"/>
        <source>E&amp;nable Battery Watcher</source>
        <translation>&amp;Aktivér overvågning af batteri</translation>
    </message>
    <message>
        <location filename="../../../batterywatchersettings.ui" line="54"/>
        <source>Warning:</source>
        <translation>Advarsel:</translation>
    </message>
    <message>
        <location filename="../../../batterywatchersettings.ui" line="67"/>
        <source> seconds</source>
        <translation> sekunder</translation>
    </message>
    <message>
        <location filename="../../../batterywatchersettings.ui" line="77"/>
        <source>Level is low at:</source>
        <translation>Niveau er lavt ved:</translation>
    </message>
    <message>
        <location filename="../../../batterywatchersettings.ui" line="90"/>
        <source> %</source>
        <translation> %</translation>
    </message>
    <message>
        <location filename="../../../batterywatchersettings.ui" line="111"/>
        <source>Use icons from theme:</source>
        <translation>Brug ikoner fra tema:</translation>
    </message>
    <message>
        <location filename="../../../batterywatchersettings.ui" line="125"/>
        <location filename="../../../batterywatchersettings.cpp" line="93"/>
        <source>Preview</source>
        <translation>Forhåndsvisning</translation>
    </message>
    <message>
        <location filename="../../../batterywatchersettings.ui" line="162"/>
        <source>Charging</source>
        <translation>Oplader</translation>
    </message>
    <message>
        <location filename="../../../batterywatchersettings.ui" line="200"/>
        <source>Discharging</source>
        <translation>Aflader</translation>
    </message>
    <message>
        <location filename="../../../batterywatchersettings.ui" line="41"/>
        <source>When power is low then:</source>
        <translation>Når strøm er lavt:</translation>
    </message>
    <message>
        <location filename="../../../batterywatchersettings.ui" line="97"/>
        <source>Show icon:</source>
        <translation>Vis ikon:</translation>
    </message>
    <message>
        <location filename="../../../batterywatchersettings.cpp" line="93"/>
        <source>built in</source>
        <translation>indbygget</translation>
    </message>
    <message>
        <location filename="../../../batterywatchersettings.cpp" line="98"/>
        <source>Level: %1%</source>
        <translation>Niveau: %1%</translation>
    </message>
</context>
<context>
    <name>IdlenessWatcherSettings</name>
    <message>
        <location filename="../../../idlenesswatchersettings.ui" line="14"/>
        <source>Form</source>
        <translation>Formular</translation>
    </message>
    <message>
        <location filename="../../../idlenesswatchersettings.ui" line="20"/>
        <source>Enab&amp;le Idleness Watcher</source>
        <translation>&amp;Aktivér overvågning af tomgang</translation>
    </message>
    <message>
        <location filename="../../../idlenesswatchersettings.ui" line="41"/>
        <source>When idle then:</source>
        <translation>Ved tomgang:</translation>
    </message>
    <message>
        <location filename="../../../idlenesswatchersettings.ui" line="60"/>
        <source>Idle time:</source>
        <translation>Tomgangstid:</translation>
    </message>
    <message>
        <location filename="../../../idlenesswatchersettings.ui" line="73"/>
        <source> minutes</source>
        <translation> minutter</translation>
    </message>
    <message>
        <location filename="../../../idlenesswatchersettings.ui" line="86"/>
        <source> seconds</source>
        <translation> sekunder</translation>
    </message>
</context>
<context>
    <name>LidWatcherSettings</name>
    <message>
        <location filename="../../../lidwatchersettings.ui" line="14"/>
        <source>Form</source>
        <translation>Formular</translation>
    </message>
    <message>
        <location filename="../../../lidwatchersettings.ui" line="26"/>
        <source>Enable &amp;Lid Watcher</source>
        <translation>&amp;Aktivér overvågning af låg</translation>
    </message>
    <message>
        <location filename="../../../lidwatchersettings.ui" line="41"/>
        <source>Action when lid is closed</source>
        <translation>Handling når låget lukkes</translation>
    </message>
    <message>
        <location filename="../../../lidwatchersettings.ui" line="53"/>
        <location filename="../../../lidwatchersettings.ui" line="118"/>
        <source>On Battery</source>
        <translation>På batteri</translation>
    </message>
    <message>
        <location filename="../../../lidwatchersettings.ui" line="61"/>
        <source>Nothing</source>
        <translation>Intet</translation>
    </message>
    <message>
        <location filename="../../../lidwatchersettings.ui" line="66"/>
        <source>Suspend</source>
        <translation>Hvile</translation>
    </message>
    <message>
        <location filename="../../../lidwatchersettings.ui" line="71"/>
        <source>Hibernate</source>
        <translation>Dvale</translation>
    </message>
    <message>
        <location filename="../../../lidwatchersettings.ui" line="76"/>
        <source>Shut down</source>
        <translation>Luk ned</translation>
    </message>
    <message>
        <location filename="../../../lidwatchersettings.ui" line="84"/>
        <location filename="../../../lidwatchersettings.ui" line="128"/>
        <source>On AC</source>
        <translation>På strømforsyning</translation>
    </message>
    <message>
        <location filename="../../../lidwatchersettings.ui" line="97"/>
        <source>When &amp;using external monitor</source>
        <translation>&amp;Når der bruges ekstern skærm</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../../../mainwindow.cpp" line="34"/>
        <source>Power Management Settings</source>
        <translation>Indstillinger for strømstyring</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.cpp" line="37"/>
        <source>Battery</source>
        <translation>Batteri</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.cpp" line="41"/>
        <source>Lid</source>
        <translation>Låg</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.cpp" line="45"/>
        <source>Idle</source>
        <translation>Tomgang</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../../helpers.cpp" line="35"/>
        <source>Nothing</source>
        <translation>Intet</translation>
    </message>
    <message>
        <location filename="../../../helpers.cpp" line="36"/>
        <source>Lock screen</source>
        <translation>Lås skærm</translation>
    </message>
    <message>
        <location filename="../../../helpers.cpp" line="37"/>
        <source>Suspend</source>
        <translation>Hvile</translation>
    </message>
    <message>
        <location filename="../../../helpers.cpp" line="38"/>
        <source>Hibernate</source>
        <translation>Dvale</translation>
    </message>
    <message>
        <location filename="../../../helpers.cpp" line="39"/>
        <source>Shutdown</source>
        <translation>Luk ned</translation>
    </message>
    <message>
        <location filename="../../../helpers.cpp" line="40"/>
        <source>Turn Off monitor(s)</source>
        <translation>Sluk skærm(e)</translation>
    </message>
</context>
</TS>
